Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateCovalentIndexer ¶
func CreateCovalentIndexer(args *ArgsCovalentIndexerFactory) (covalent.Driver, error)
CreateCovalentIndexer creates a new Driver instance of type covalent data indexer
Types ¶
type ArgsCovalentIndexerFactory ¶
type ArgsCovalentIndexerFactory struct {
Enabled bool
URL string
RouteSendData string
RouteAcknowledgeData string
PubKeyConverter core.PubkeyConverter
Accounts covalent.AccountsAdapter
Hasher hashing.Hasher
Marshaller marshal.Marshalizer
ShardCoordinator process.ShardCoordinator
}
ArgsCovalentIndexerFactory holds all input dependencies required by covalent data indexer factory in order to create new instances
Click to show internal directories.
Click to hide internal directories.